@@ -287,17 +287,19 @@ class Client(commandServer, encrypt, Desktop):
         else:
             nomapposix = ",nomapposix"
         cache_method = self.clVars.Get('cl_cifs_cache')
+        cifs_mount_vers = self.clVars.Get('cl_cifs_mount_vers')
         if not uid is None:
             # mount by uid
             p = process(mountCmd, "-t", "cifs", "-o",
-                        "cache=%s,user=%s,uid=%d,gid=%d,noperm%s" % (
-                            cache_method, userName, uid, gid, nomapposix),
+                        "cache=%s,vers=%s,user=%s,uid=%d,gid=%d,noperm%s" % (
+                            cache_method, cifs_mount_vers, userName, uid, gid, nomapposix),
                         "//%s/%s" % (host, res), rpath,
                         envdict={"PASSWD": userPwd}, stderr=STDOUT)
             return p.success()
         else:
             p = process(mountCmd, "-t", "cifs", "-o",
-                        "cache=%s,user=%s%s" % (cache_method, userName, nomapposix),
+                        "cache=%s,vers=%s,user=%s%s" % (cache_method,
+                            cifs_mount_vers, userName, nomapposix),
                         "//%s/%s" % (host, res), rpath,
                         envdict={"PASSWD": userPwd}, stderr=STDOUT)
             return p.success()
