@@ -743,6 +743,12 @@ class VariableClCifsCache(Variable):
     """
     value = "loose"
 
+class VariableClCifsMountVers(Variable):
+    """
+    Параметр vers= для cifs
+    """
+    value = "1.0"
+
 
 class VariableClRsyncVer(ReadonlyVariable):
     """
